<?php
// https://www.muziekweb.nl/Muziekweb/Webservice/Example/Search.Ajax.php?q=madonna
// Limit q to 100 chars
require_once('Bootstrap.php');
require_once('Search.Lib.php');

$pQ = empty($_REQUEST['q']) ? false : trim(substr($_REQUEST['q'], 0, 100));
$pCatalogue = empty($_REQUEST['catalogue']) ? 'auto' : strtolower($_REQUEST['catalogue']);


// Is there a valid search input
if ($pQ === false || empty($pQ))
{
  // Stop executing en empty buffer
  return false;
}

// test case: "meatloaf"
$client = new \Zend_Rest_Client(WEB_REST_SERVICE.'/Search/v3/SingleSearch/SingleSearch.xml'.
        '?q='.urlencode($pQ).
        '&highlight=1'.
        '&website=example.com'.
        '&html=1'.
        '&realtime=1');
$wsResult = $client->get();
unset($client);

// Check of we wel data weer te geven hebben
if (!is_object($wsResult) || !(isset($wsResult->Result['ErrorCode']) && intval($wsResult->Result['ErrorCode']) === 0) ||
    intval($wsResult->Result->Popular->Performers['Count']) +
    intval($wsResult->Result->Popular->Albums['Count']) +
    intval($wsResult->Result->Popular->Songs['Count']) +
    intval($wsResult->Result->Popular->OrderData['Count']) +
    intval($wsResult->Result->Classical->Composers['Count']) +
    intval($wsResult->Result->Classical->Performers['Count']) +
    intval($wsResult->Result->Classical->WorkTitles['Count']) +
    intval($wsResult->Result->Classical->Performances['Count']) +
    intval($wsResult->Result->Classical->Albums['Count']) +
    intval($wsResult->Result->Classical->OrderData['Count']) +
    intval($wsResult->Result->Labels['Count']) +
    intval($wsResult->Result->Styles['Count']) === 0)
{
  // Stop executing if empty
  return false;
}

$popTotalHits = intval($wsResult->Result->Popular['TotalHits']) + intval($wsResult->Result->Labels['Count']);
$clasTotalHits = intval($wsResult->Result->Classical['TotalHits']) + intval($wsResult->Result->Labels['Count']);
$popTotalHitsStr = ($popTotalHits > 1000) ? '1000+' : strval($popTotalHits);
$clasTotalHitsStr = ($clasTotalHits > 1000) ? '1000+' : strval($clasTotalHits);

switch ($pCatalogue)
{
  case 'pop':
    // Alleen geen pop doen als we geen pop en wel klassieke resultaten hebben
    $doPop = ($popTotalHits > 0 || $clasTotalHits <= 0);
    break;
  case 'clas':
    // Alleen pop doen als we geen klassieke resultaten hebben
    $doPop = ($popTotalHits > 0 && $clasTotalHits == 0);
    break;
  default:
    $pCatalogue = 'auto';
    // Pop weergeven als we op 2 letters zoeken (te veel resultaten), of als
    // er een meerderheid pop is, of als er geen klassieke resultaten zijn.
    $doPop = (strlen($pQ) <= 2 || intval($wsResult->Result->SingleSearchResult['PopularPercentage']) >= 50 || $clasTotalHits <= 0);
    break;
} //switch

$PAGE = '';


$PAGE .= '<div>'.PHP_EOL;
$PAGE .= '<div style="display: inline-block;width:49%;vertical-align:top;">'.PHP_EOL;
$PAGE .= '<table border="1" style="width:100%">'.PHP_EOL;
/*
 * Pop artist
 */
if (intval($wsResult->Result->Popular->Performers['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Artist</td>';
  $first = true;
  foreach ($wsResult->Result->Popular->Performers->Performer as $performer)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderPopularPerformer($performer).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}

/*
 * Pop albums
 */
if (intval($wsResult->Result->Popular->Albums['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Albums</td>';
  $first = true;
  foreach ($wsResult->Result->Popular->Albums->Album as $album)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderPopularAlbum($album).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}

/*
 * Pop songs
 */
if (intval($wsResult->Result->Popular->Songs['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Songs</td>';
  $first = true;
  foreach ($wsResult->Result->Popular->Songs->Song as $song)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $url = 'uniformtitlepop.php?Link='.urlencode($song->AlbumTrackID);
    $PAGE .= '<td>'.RenderPopularSong($song).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}
$PAGE .= '</table>'.PHP_EOL;
$PAGE .= '</div>'.PHP_EOL;


$PAGE .= '<div style="display: inline-block;width:49%;vertical-align:top">'.PHP_EOL;
$PAGE .= '<table border="1" style="width:100%">'.PHP_EOL;
if (intval($wsResult->Result->Classical->Composers['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Composers</td>';
  $first = true;
  foreach ($wsResult->Result->Classical->Composers->Performer as $performer)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderClassicalComposer($performer).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}

if (intval($wsResult->Result->Classical->Performers['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Performers</td>';
  $first = true;
  foreach ($wsResult->Result->Classical->Performers->Performer as $performer)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderClassicalPerformer($performer).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}

if (intval($wsResult->Result->Classical->WorkTitles['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Worktitles</td>';
  $first = true;
  foreach ($wsResult->Result->Classical->WorkTitles->Work as $work)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderClassicalWorkTitle($work).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}

if (intval($wsResult->Result->Classical->Performances['Count']) > 0)
{
  $PAGE .= '<tr><td style="vertical-align: top;">Performances</td>';
  $first = true;
  foreach ($wsResult->Result->Classical->Performances->Work as $performance)
  {
    if (!$first)
    {
      $PAGE .= '<tr><td></td>';
    }
    $PAGE .= '<td>'.RenderClassicalPerformance($performance).'</td>'.PHP_EOL;
    $first = false;
  } //foreach
  $PAGE .= '</tr>'.PHP_EOL;
}
$PAGE .= '</table>'.PHP_EOL;
$PAGE .= '</div>'.PHP_EOL;
$PAGE .= '</div>'.PHP_EOL;
?>

<div>
  <div style="display: inline-block;width:49%;vertical-align:top;font-weight: bold;">
    Popular
  </div>
  <div style="display: inline-block;width:49%;vertical-align:top;font-weight: bold;">
    Classical
  </div>
</div>

<?php

echo $PAGE;
