<?php
function URL_Cover($album, $size = 'SMALL', $side = 'FRONT')
{
  if (is_object($album) && isset($album->AlbumID))
  {
    $AlbumID = $album->AlbumID;
  }
  else
  {
    $AlbumID = $album;
  }

  switch($size)
  {
    case 'PICO':      //  60 x  60
    case 'SMALL':     // 120 x 120
    case 'MEDIUM':    // 240 x 240
    case 'LARGE':     // 400 x 400
    case 'SUPERLARGE':// 800 x 800
    case 'ORG':       // Origional size
      break;
    default:
      $size = 'SMALL';
  }

  switch($side)
  {
    case 'FRONT':
    case 'BACK':
      break;
    default:
      $side = 'FRONT';
      break;
  }

  return "https://media.cdr.nl/COVER/$size/$side/$AlbumID.jpg";
}

function URL_UniformTitleClassical($work)
{
  if (strlen($work->UniformTitle['Link']) > 0)
  {
    return 'Classical-Performance.php?Link='.$work->UniformTitle['Link'];
  }
  return '';
}

function SetAnchor($url, $text)
{
  if (strlen($url) > 0)
  {
    return '<a href="'.$url.'">'.$text.'</a>';
  }
  else
  {
    return $text;
  }
}

// ============================================================================================================================

function RenderPopularPerformer(&$performer)
{
  $url = 'Pop-PerformerAlbums.php?Link='.urlencode($performer['Link']);

  if (isset($performer->Article) && strlen($performer->Article) > 0)
  {
    return '<span><a href="'.$url.'">'.$performer->PresentationName.'</a></span><span><span class="cat-info-icon" title="Review available"> (i)</span></span>'.PHP_EOL;
  }
  else
  {
    return '<a href="'.$url.'">'.$performer->PresentationName.'</a>'.PHP_EOL;
  }
}

function RenderPopularAlbum(&$album)
{
  $url = 'Album.php?AlbumID='.urlencode($album->AlbumID);

  $performerStr = '';
  foreach ($album->Performers->Performer as $performer)
  {
    if (!empty($performerStr))
    {
      $performerStr .= ' & ';
    }
    $performerStr .= $performer->PresentationName;
  } //foreach

  if (isset($album->AlbumArticle) && strlen($album->AlbumArticle) > 0)
  {
    return '<span><a href="'.$url.'">'.$album->AlbumTitle.'</a></span><span><span class="cat-info-icon" title="Review available"> (i)</span></span> - <span>'.$performerStr.'</span>'.PHP_EOL;
  }
  else
  {
    return '<a href="'.$url.'">'.$album->AlbumTitle.'</a>'.PHP_EOL;
  }
}

function RenderPopularSong(&$song)
{
  $result = '';
  $url = 'Album.php?AlbumID='.urlencode($song->Album->AlbumID).'&TrackID='.urlencode($song->AlbumTrackID);

  $cover = URL_Cover($song->Album, 'PICO');

  $seconden = strval($song->PlayTimeInSec);
  $min = floor($seconden / 60);
  $sec = str_pad($seconden - (floor($seconden / 60) * 60), 2, '0', STR_PAD_LEFT);
  $playTime = $min . ':' . $sec;

  $songPerformers = '';
  foreach ($song->Performers->Performer as $performer)
  {
    if (!empty($songPerformers))
    {
      $songPerformers .= ' & ';
    }
    $songPerformers .= $performer->PresentationName;
  } //foreach

  $result .= '<span><a href="'.$url.'">'.$song->SongTitle.'</a> <span class="songPlayTime">('.$playTime.')</span> - </span>'.
             '<span>'.$songPerformers.'</span>'.PHP_EOL;

  return $result;
}

function RenderClassicalComposer(&$performer)
{
  $url = 'Classical-ComposerWork.php?Link='.urlencode($performer['Link']);

  if (isset($performer->Article) && strlen($performer->Article) > 0)
  {
    return '<span><a href="'.$url.'">'.$performer->PresentationName.'</a></span><span><span class="cat-info-icon" title="Review available"> (i)</span></span>'.PHP_EOL;
  }
  else
  {
    return '<a href="'.$url.'">'.$performer->PresentationName.'</a>'.PHP_EOL;
  }
}

function RenderClassicalPerformer(&$performer)
{
  $url = 'Classical-Performance.php?Link='.urlencode($performer['Link']);

  if (isset($performer->Article) && strlen($performer->Article) > 0)
  {
    return '<span><a href="'.$url.'">'.$performer->PresentationName.'</a></span><span><span class="cat-info-icon" title="Review available"> (i)</span></span>'.PHP_EOL;
  }
  else
  {
    return '<a href="'.$url.'">'.$performer->PresentationName.'</a>'.PHP_EOL;
  }
}

function RenderClassicalWorkTitle(&$work)
{
  $url = '';
  if (strlen($work->UniformTitle['Link']) > 0)
  {
    $url = 'Classical-Performance.php?Link='.urlencode($work->UniformTitle['Link']);
  }

  $result = '';
  $title = str_replace('"', '&quot;', $work->Performer->PresentationName.'&#10;'.$work->UniformTitle);

  if (empty((string)$work->Performer->PresentationName))
  {
    $result .= '<span>'.SetAnchor($url, $work->UniformTitle).'</span>'.PHP_EOL;
  }
  else
  {
    $result .= SetAnchor($url, '<span>'.$work->Performer->PresentationName.'</span> - '.
                 '<span>'.$work->UniformTitle.'</span>').
               PHP_EOL;
  }

  return $result;
}

function RenderClassicalPerformance($performance)
{
  $url = 'Album.php?AlbumID='.urlencode($performance->Album->AlbumID).'&WorkID='.urlencode((string)$performance->UniformTitle['Link']);

  $result = '';

  $cover = URL_Cover($performance->Album, 'PICO');
  $componistsStr = '';
  $performersStr = '';
  $count = 0;
  foreach ($performance->Performers->Performer as $performer)
  {
    if ($performer->Role['Code'] == 'COMPOSER')
    {
      if (!empty($componistsStr))
      {
        continue;
      }
      $componistsStr = $performer->PresentationName;
    }
    else
    {
      if (!empty($performersStr))
      {
        $performersStr .= ' & ';
      }
      $performersStr .= $performer->PresentationName;
      $count++;
    }
  } //foreach

  $result .= '<a href="'.$url.'">'.
             (empty($componistsStr) ? '' : '<span>'.$componistsStr.'</span> - ').
             '<span>'.$performance->UniformTitle.'</span> - '.
             '<span>'.$performersStr.'</div>'.
             '</a>'.
             PHP_EOL;

  return $result;
}

// ============================================================================================================================

function RenderPagingLine(&$resultInfo, $pagingUrl)
{
  $pagingLine = '';
  // Show previous page?
  if (intval($resultInfo->Range->ReturnedRangeStart) > 1)
  {
    $start = intval($resultInfo->Range->ReturnedRangeStart);
    if (($start - 20) < 1)
    {
      $start = 1;
    }
    else
    {
      $start = $start - 20;
    }
    $pagingLine .= '<a href="'.$pagingUrl.'&RangeStart='.$start.'&RangeEnd='.($start+19).'">Previous page</a>';
  }
  else
  {
    $pagingLine .= 'Previous page';
  }
  $pagingLine .= '&nbsp;-&nbsp;';
  if (intval($resultInfo->Range->ReturnedRangeEnd) < intval($resultInfo->MediaHits->Hits))
  {
    $start = intval($resultInfo->Range->ReturnedRangeStart);
    $pagingLine .= '<a href="'.$pagingUrl.'&RangeStart='.($start+20).'&RangeEnd='.($start+39).'">Next page</a>';
  }
  else
  {
    $pagingLine .= 'Next page';
  }

  return $pagingLine;
}

function RenderPagingPosition(&$resultInfo)
{
  return '<div style="font-weight:bold">'.strval($resultInfo->Range->ReturnedRangeStart).' - '.strval($resultInfo->Range->ReturnedRangeEnd).' of '.strval($resultInfo->MediaHits->Hits).' albums</div>';
}

function RenderList_Albums(&$datasetAlbums, &$wsResultPerformer, $pagingUrl)
{
  $result = '';
  $counter = 0;

  $pagingLine = RenderPagingLine($datasetAlbums->Result->ResultInfo, $pagingUrl);

  $result = RenderPagingPosition($datasetAlbums->Result->ResultInfo).
            '<br>'.
            '<center>'.$pagingLine.'</center><br>';

  foreach($datasetAlbums->Albums->Album as $album)
  {
    $counter++;
    $urlAlbum = 'Album.php?AlbumID='.urlencode($album->AlbumID);
    $urlCover = URL_Cover($album, 'SMALL');

    $performerStr = '';
    foreach($album->Performers->Performer as $performer)
    {
      if (strlen($performerStr) > 0)
      {
        $performerStr .= ' & ';
      }

      if ($album->Catalogue == 'CLASSICAL')
      {
        if ($performer->Role['Code'] == 'COMPOSER')
        {
          $performerStr .= $performer->PresentationName;
        }

      }
      else
      {
        $performerStr .= $performer->PresentationName;
      }
    } //foreach performer

    $result .= '<div>'.PHP_EOL.
               '<a href="'.$urlAlbum.'"><img style="float:left" src="'.$urlCover.'"></a>'.
               '<div style="float:left">&nbsp;</div>'.
               '<div style="float:left">'.
               $album->AlbumTitle;
    if (strlen($performerStr) > 0)
    {
       $result .= '<br>'.PHP_EOL.
                  $performerStr;
    }
    $result .= '</div>'.
               '</div>'.PHP_EOL.
               '<div style="clear: both;">&nbsp;</div>'.PHP_EOL;
  } //foreach
  $result .= '<center>'.$pagingLine.'</center><br>';




  return $result;
}

// TODO!!!
function RenderList_Songs(&$datasetAlbums, &$wsResultPerformer, $pagingUrl)
{
  $result = '';
  $counter = 0;

  $pagingLine = RenderPagingLine($datasetAlbums->Result->ResultInfo, $pagingUrl);

  $result = RenderPagingPosition($datasetAlbums->Result->ResultInfo).
            '<br>'.
            '<center>'.$pagingLine.'</center><br>';

  foreach($datasetAlbums->Album as $album)
  {
    $counter++;
    $urlAlbum = 'Album.php?AlbumID='.urlencode($album->AlbumID);
    $urlCover = URL_Cover($album, 'SMALL');

    $performerStr = '';
    foreach($album->Performers->Performer as $performer)
    {
      if (strlen($performerStr) > 0)
      {
        $performerStr .= ' & ';
      }

      if ($album->Catalogue == 'CLASSICAL')
      {
        if ($performer->Role['Code'] == 'COMPOSER')
        {
          $performerStr .= $performer->PresentationName;
        }

      }
      else
      {
        $performerStr .= $performer->PresentationName;
      }
    } //foreach performer

    $result .= '<div>'.PHP_EOL.
               '<a href="'.$urlAlbum.'"><img style="float:left" src="'.$urlCover.'"></a>'.
               '<div style="float:left">&nbsp;</div>'.
               '<div style="float:left">'.
               $album->AlbumTitle;
    if (strlen($performerStr) > 0)
    {
       $result .= '<br>'.PHP_EOL.
                  $performerStr;
    }
    $result .= '</div>'.
               '</div>'.PHP_EOL.
               '<div style="clear: both;">&nbsp;</div>'.PHP_EOL;
  } //foreach
  $result .= '<center>'.$pagingLine.'</center><br>';




  return $result;
}


function RenderList_ComposerWork(&$dataset, &$wsResultPerformer, $pagingUrl)
{
  $result = '';

  $pagingLine = RenderPagingLine($dataset->Result->ResultInfo, $pagingUrl);

  $result = RenderPagingPosition($dataset->Result->ResultInfo).
            '<br>'.
            '<center>'.$pagingLine.'</center><br>';

  $result .= '<table styler="width:100%">';
  $counter = 0;
  foreach($dataset->Work as $work)
  {
    $counter++;
    $url = URL_UniformTitleClassical($work);

    $result .= '<tr>'.PHP_EOL.
               '<td><a href="'.$url.'">'.htmlentities($work->UniformTitle).'</a></td>'.
               '<td>&nbsp;</td>'.
               '<td>'.htmlentities($work->Performer->PresentationName).'</td>'.
               '<tr>'.PHP_EOL;
  }
  $result .= '</table>'.PHP_EOL;
  $result .= '<center>'.$pagingLine.'</center><br>';

  return $result;
}


function RenderList_Performance(&$dataset, &$wsResultPerformer, $pagingUrl)
{
  $result = '';

  $pagingLine = RenderPagingLine($dataset->Result->ResultInfo, $pagingUrl);

  $result = RenderPagingPosition($dataset->Result->ResultInfo).
            '<br>'.
            '<center>'.$pagingLine.'</center><br>';

  $result .= '<table styler="width:100%">';
  $counter = 0;
  foreach($dataset->Performance->Work as $work)
  {
    $counter++;
    if ($counter > 1)
    {
      $result .= '<tr><td>&nbsp;</td></tr>'.PHP_EOL;
    }

    $urlCover = URL_Cover($work->Album, 'SMALL');
    $url = 'Album.php?AlbumID='.urlencode($work->Album->AlbumID);

    $composerStr = '';
    $performerStr = '';
    foreach($work->Performers->Performer as $performer)
    {
      if ($work->Album->Catalogue == 'CLASSICAL')
      {
        if ($performer->Role['Code'] == 'COMPOSER')
        {
          if (strlen($composerStr) > 0)
          {
            $composerStr .= ' & ';
          }
          $composerStr .= '<i><a href="Classical-ComposerWork.php?Link='.urlencode($performer['Link']).'">'.$performer->PresentationName.'</a></i>';
        }
        else
        {
          if (strlen($performerStr) > 0)
          {
            $performerStr .= ' <br> ';
          }
          if ($performer['Link'])
          {
            $performerStr .= '<a href="Classical-Performance.php?PerformerLink='.urlencode($performer['Link']).'">'.$performer->PresentationName.'</a>';
          }
          else
          {
            $performerStr .= $performer->PresentationName;
          }
        }

      }
      else
      {
        if (strlen($performerStr) > 0)
        {
          $performerStr .= '<br>';
        }

        $performerStr .= $performer->PresentationName;
      }
    } //foreach performer

    if (strlen($work->UniformTitle) > 0)
    {
      $workTitle = '<a href="Classical-Performance.php?PerformerLink='.urlencode($work->UniformTitle['Link']).'">'.htmlentities($work->UniformTitle).'</a>';
    }
    else
    {
      $workTitle = htmlentities($work->WorkTitle);
    }

    $result .= '<tr>'.PHP_EOL.
               '<td style="vertical-align: top;"><a href="'.$url.'"><img src="'.$urlCover.'"></a></td>'.
               '<td></td>'.
               '<td style="vertical-align: top;">'.$workTitle;
    if ($composerStr)
    {
      $result .= '<br>'.$composerStr;
    }
    $result .= '</td>'.
               '<td></td>'.
               '<td style="vertical-align: top;">'.$performerStr.'</td>'.
               '</tr>'.PHP_EOL;
  }
  $result .= '</table>'.PHP_EOL;
  $result .= '<center>'.$pagingLine.'</center><br>';

  return $result;
}
